package sun.security.validator;

import sun.security.util.Debug;
import java.security.AccessController;
import java.security.Security;
import java.security.PrivilegedAction;
import java.security.cert.X509Certificate;
import java.util.EnumSet;

enum CADistrustPolicy
{
    SYMANTEC_TLS {
        @Override
        void checkDistrust(String s, X509Certificate[] array) throws ValidatorException {
            if (!s.equals("tls server")) {
                return;
            }
            SymantecTLSPolicy.checkDistrust(array);
            return;
        }
    };
    
    static final EnumSet<CADistrustPolicy> POLICIES;
    
    abstract void checkDistrust(String p0, X509Certificate[] p1) throws ValidatorException;
    
    private static EnumSet<CADistrustPolicy> parseProperty() {
        String s = (String)AccessController.doPrivileged(new PrivilegedAction<String>() {
            @Override
            public String run() {
                return Security.getProperty("jdk.security.caDistrustPolicies");
            }
        });
        EnumSet<CADistrustPolicy> none = EnumSet.noneOf(CADistrustPolicy.class);
        if (s == null || s.isEmpty()) {
            return none;
        }
        String[] split = s.split(",");
        for (int length = split.length, i = 0; i < length; ++i) {
            String trim = split[i].trim();
            try {
                none.add((CADistrustPolicy)Enum.valueOf(CADistrustPolicy.class, trim));
            }
            catch (IllegalArgumentException ex) {
                Debug instance = Debug.getInstance("certpath");
                if (instance != null) {
                    instance.println("Unknown value for the jdk.security.caDistrustPolicies property: " + trim);
                }
            }
        }
        return none;
    }
    
    CADistrustPolicy(String s, int n, CADistrustPolicy.1 caDistrustPolicy) {
        this();
    }
    
    static {
        POLICIES = parseProperty();
    }
}
